SecurityStatus class

Security check result returned from the native layer.

Constructors

SecurityStatus({required bool isFridaDetected, required bool isProxyOrVpnDetected})
const
SecurityStatus.fromMap(Map map)
Creates an instance from the map returned via MethodChannel.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isAttacked bool
true if any threat is detected.
no setter
isFridaDetected bool
true if Frida or a similar hooking tool is running.
final
isProxyOrVpnDetected bool
true if a system Proxy or VPN is active.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

safe → const SecurityStatus
Default safe status (no threats detected).